@@ -1,11 +1,11 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "moody" "1.2.2"
+(define-package "moody" "20251019.1908"
   "Tabs and ribbons for the mode line."
   '((emacs  "28.1")
     (compat "30.1"))
   :url "https://github.com/tarsius/moody"
-  :commit "82f65014dcdfc7178464c282b5c9ec5f7016c945"
-  :revdesc "v1.2.2-0-g82f65014dcdf"
+  :commit "53cb66babe12750924484bd6d914e1f4fd0cb9db"
+  :revdesc "53cb66babe12"
   :keywords '("faces")
   :authors '(("Jonas Bernoulli" . "emacs.moody@jonas.bernoulli.dev"))
   :maintainers '(("Jonas Bernoulli" . "emacs.moody@jonas.bernoulli.dev")))
